@@ -1,5 +1,5 @@
 /*****************************************************************************\
- *  $Id: hostlist.c,v 1.3 2008/01/29 19:09:05 chu11 Exp $
+ *  $Id: hostlist.c,v 1.4 2008/07/11 22:37:28 chu11 Exp $
  *****************************************************************************
  *  Copyright (C) 2002 The Regents of the University of California.
  *  Produced at Lawrence Livermore National Laboratory (cf, DISCLAIMER).
@@ -906,22 +906,48 @@ static hostrange_t hostrange_intersect(hostrange_t h1, hostrange_t h2)
  */
 static int hostrange_hn_within(hostrange_t hr, hostname_t hn)
 {
-    int retval = 0;
-
-    if (hr->singlehost && (strcmp(hn->hostname, hr->prefix) == 0))
-        return 1;
-
-    if (strcmp(hr->prefix, hn->prefix) == 0) {
-        if (!hostname_suffix_is_valid(hn)) {
-            if (hr->singlehost)
-                retval = 1;
-        } else if (hn->num <= hr->hi && hn->num >= hr->lo) {
-            int width = hostname_suffix_width(hn);
-            int num = hn->num;
-            retval = _width_equiv(hr->lo, &hr->width, num, &width);
-        }
+    if (hr->singlehost) {
+        /*  
+         *  If the current hostrange [hr] is a `singlehost' (no valid 
+         *   numeric suffix (lo and hi)), then the hostrange [hr]
+         *   stores just one host with name == hr->prefix.
+         *  
+         *  Thus the full hostname in [hn] must match hr->prefix, in
+         *   which case we return true. Otherwise, there is no 
+         *   possibility that [hn] matches [hr].
+         */
+        if (strcmp (hn->hostname, hr->prefix) == 0)
+            return 1;
+        else 
+            return 0;
     }
-    return retval;
+
+    /*
+     *  Now we know [hr] is not a "singlehost", so hostname
+     *   better have a valid numeric suffix, or there is no 
+     *   way we can match
+     */
+    if (!hostname_suffix_is_valid (hn))
+        return 0;
+
+    /*
+     *  If hostrange and hostname prefixes don't match, then
+     *   there is way the hostname falls within the range [hr].
+     */
+    if (strcmp(hr->prefix, hn->prefix) != 0) 
+        return 0;
+
+    /*
+     *  Finally, check whether [hn], with a valid numeric suffix,
+     *   falls within the range of [hr].
+     */
+    if (hn->num <= hr->hi && hn->num >= hr->lo) {
+        int width = hostname_suffix_width(hn);
+        int num = hn->num;
+        return (_width_equiv(hr->lo, &hr->width, num, &width));
+    }
+
+    return 0;
 }
 
 
